<?php

namespace App\Http\Livewire;

use Livewire\Component;
use App\Models\Productos as Producto;
use App\Models\CategoriaProducto;
use Livewire\WithPagination;
use Illuminate\Pagination\Paginator;
use Illuminate\Support\Facades\DB;

class Productos extends Component
{
    use WithPagination;

    public $search = '';
    public $categorias, $buscador, $clave_producto, $tipo_producto, $descripcion_producto, $categoria_producto_id, $marca_producto, $costo_compra, $precio_venta, $presentacion_producto;
    public $updateMode = false;

    public function updatingSearch()
    {
        $this->resetPage();
    }

    public function render()
    {

        $this->categorias = CategoriaProducto::all();
        $perPage = 10;
        $collection = DB::table('productos')
        ->join('categoria_producto', 'productos.categoria_producto_id', '=', 'categoria_producto.id')
        ->select('productos.clave_producto', 'productos.tipo_producto','productos.descripcion_producto', 'productos.categoria_producto_id','productos.marca_producto','productos.costo_compra','productos.precio_venta','productos.presentacion_producto','productos.id','categoria_producto.descripcion as categoria')
        ->get();;

        $offset = max(0, ($this->page - 1) * $perPage);
        // need one more here so the simple paginatior knows
        // if there are more pages left
        $items = $collection->slice($offset, $perPage + 1);
        $paginator = new Paginator($items, $perPage, $this->page);
        return view('livewire.Productos.productos', ['data' => $paginator]);
    }

    public function resetInput()
    {
        $this->clave_producto = null;
        $this->tipo_producto = null;
        $this->descripcion_producto = null;
        $this->categoria_producto_id = null;
        $this->marca_producto = null;
        $this->costo_compra = null;
        $this->precio_venta = null;
        $this->presentacion_producto = null;
    }

    public function store()
    {
        $this->validate([
            'descripcion_producto' => 'required|min:2',
            'clave_producto' => 'required|min:2',
        ]);
        Producto::create([
            'clave_producto' => $this->clave_producto,
            'tipo_producto' => $this->tipo_producto,
            'descripcion_producto' => $this->descripcion_producto,
            'categoria_producto_id' => $this->categoria_producto_id,
            'marca_producto' => $this->marca_producto,
            'costo_compra' => $this->costo_compra,
            'precio_venta' => $this->precio_venta,
            'presentacion_producto' => $this->presentacion_producto,
        ]);

        $this->resetInput();
    }
}
